@@ -16,6 +16,7 @@ class Database(syst3m.objects.Traceback):
 		if firestore == None and path == None: raise exceptions.InvalidUsage(self.__traceback__()+" Both parameters firestore & path are None.")
 
 		# attributes.
+		self.mode = "firestore"
 		self.firestore = firestore
 		self.path = gfp.clean(path)
 		self.file_path = self.fp = FilePath(self.path)
@@ -25,37 +26,54 @@ class Database(syst3m.objects.Traceback):
 			Files.chmod(path=self.path, permission=700, sudo=True)
 			Files.chown(path=self.path, owner=syst3m.defaults.vars.user, group=syst3m.defaults.vars.group, sudo=True)
 		self.cache = None
-		if self.firestore == None:
+		if firestore == None:
+			self.mode = "cache"
 			self.cache = syst3m.cache.Cache(path=self.path)
 
 		#
+
+	# functions.
 	def load(self, path=None, format="str"):
 		if path == None: return r3sponse.error(self.__traceback__(function="load")+" Define parameter: [path].")
-		if self.firestore != None:
+		if self.mode == "firestore":
 			return self.firestore.load(path)
-		elif self.cache != None:
-			return self.cache.load(group=path, format=format)
-		else: raise exceptions.InvalidUsage(self.__traceback__(function="load")+" Both parameters firestore & path are None.")
+		elif self.mode == "cache":
+			try:
+				data = self.cache.load(group=path, format=format)
+			except Exception as e: return r3sponse.error(str(e))
+			return r3sponse.success(f"Successfully loaded [{path}].", {
+				"data":data,
+			})
+		else: raise exceptions.InvalidUsage(self.__traceback__(function="load")+f" Unknown mode [{self.mode}].")
 	def save(self, path=None, data=None, format="str"):
 		if path == None: return r3sponse.error(self.__traceback__(function="save")+" Define parameter: [path].")
 		if data == None: return r3sponse.error(self.__traceback__(function="save")+" Define parameter: [data].")
-		if self.firestore != None:
+		if self.mode == "firestore":
 			return self.firestore.save(path, data)
-		elif self.cache != None:
+		elif self.mode == "cache":
 			try:
 				self.cache.save(group=path, data=data, format=format)
 			except Exception as e: return r3sponse.error(str(e))
 			return r3sponse.success(f"Successfully saved [{path}].")
-		else: raise exceptions.InvalidUsage(self.__traceback__(function="save")+" Both parameters firestore & path are None.")
+		else: raise exceptions.InvalidUsage(self.__traceback__(function="save")+f" Unknown mode [{self.mode}].")
 	def delete(self, path=None, data=None, format="str"):
 		if path == None: return r3sponse.error(self.__traceback__(function="delete")+" Define parameter: [path].")
-		if self.firestore != None:
+		if self.mode == "firestore":
 			return self.firestore.delete(path)
-		elif self.cache != None:
-			return self.cache.delete(group=path)
-		else: raise exceptions.InvalidUsage(self.__traceback__(function="delete")+" Both parameters firestore & path are None.")
-	# str representation.
+		elif self.mode == "cache":
+			try:
+				self.cache.delete(group=path)
+			except Exception as e: return r3sponse.error(str(e))
+			return r3sponse.success(f"Successfully deleted [{path}].")
+		else: raise exceptions.InvalidUsage(self.__traceback__(function="delete")+f" Unknown mode [{self.mode}].")
+
+	# representation.
 	def __str__(self):
 		return str(self.fp.path)
+	def __repr__(self):
+		return str(self)
+
+	#
+
 	
 			
\ No newline at end of file
